@@ -12,8 +12,8 @@ test_that("flow works", {
     geometry = sf::st_sfc(lapply(1:nrows, function(x) sf::st_geometrycollection()))
   ))
   expect_error(flow(aoi = x), "'aoi' has empty entries in the geometry column.")
-  expect_error(flow(aoi = c(1, 2, 3)), "'aoi' must be an sf object.")
-  expect_error(flow(aoi = NA), "'aoi' must be an sf object.")
+  expect_error(flow(aoi = c(1, 2, 3)), "'aoi' must be an sf or sfc object.")
+  expect_error(flow(aoi = NA), "'aoi' must be an sf or sfc object.")
   expect_error(flow(aoi = poi), "'aoi' must be an sf object with geometry type 'POLYGON' or 'MULTIPOLYGON'.")
   expect_error(flow(aoi = aoi, min_jam_factor = -1), "'min_jam_factor' must be in the valid range from 0 to 10.")
   expect_error(flow(aoi = aoi, min_jam_factor = "11"), "'min_jam_factor' must be of type 'numeric'.")
